gleedoc
Types
Configuration for a gleedoc run.
pub type GleedocConfig {
GleedocConfig(
extra_imports: List(String),
source_dir: String,
output_dir: String,
)
}
Constructors
-
GleedocConfig( extra_imports: List(String), source_dir: String, output_dir: String, )Arguments
- extra_imports
-
A list of imports that will automatically be applied to every generated test file. Example:
["gleam/int", "gleam/otp/actor"] - source_dir
-
Directory to read source files from, typically “src”
- output_dir
-
Directory to write generated tests to, typically “test”
Values
pub fn run(config: GleedocConfig) -> Result(Nil, snag.Snag)
Run gleedoc on a project, extracting doc tests from source files and generating test files in the output directory.